from stimulsoft_reports.export.enums import StiDataType

from ..export.enums import StiDashboardExportFormat
from .StiDashboardExportSettings import StiDashboardExportSettings


class StiDataDashboardExportSettings(StiDashboardExportSettings):

### Properties

    dataType: StiDataType = StiDataType.CSV
    """[enum] Specifies the type of the data."""


### Helpers

    def getExportFormat(self):
        return StiDashboardExportFormat.DATA



from stimulsoft_reports.classes.StiFileResult import StiFileResult
from stimulsoft_reports.resources.StiResourcesHelper import StiResourcesHelper as StiReportResourcesHelper

from .scripts.StiScriptResource import StiScriptResource


class StiResourcesHelper:

### Public
    
    def getResult(name: str) -> StiFileResult:
        if len(name or '') == 0:
            return StiFileResult.getError('Resource name not specified.')
        
        if (name.endswith('.js') and name.startswith('stimulsoft.dashboards')):
            return StiScriptResource.getResult(name)
        
        return StiReportResourcesHelper.getResult(name)
    


from ..export.enums import StiDashboardExportFormat, StiDashboardScaleMode
from .StiDashboardExportSettings import StiDashboardExportSettings


class StiHtmlDashboardExportSettings(StiDashboardExportSettings):

### Properties

    scaleMode: StiDashboardScaleMode = StiDashboardScaleMode.VIEW_SIZE
    """[enum] Specifies the scaling mode of the dashboard content."""

    imageQuality: int = 200
    """The image quality of images which will be exported to a result file."""

    scale: int = 100
    """The scale of an exported document."""

    enableAnimation: bool = True
    """Enables or disables animation of dashboard elements in the exported HTML file."""


### Helpers

    def getExportFormat(self):
        return StiDashboardExportFormat.HTML
    


from stimulsoft_reports.export.enums import StiImageType

from ..export.enums import StiDashboardExportFormat, StiDashboardScaleMode
from .StiDashboardExportSettings import StiDashboardExportSettings


class StiImageDashboardExportSettings(StiDashboardExportSettings):

### Properties

    scaleMode: StiDashboardScaleMode = StiDashboardScaleMode.VIEW_SIZE
    """[enum] Specifies the scaling mode of the dashboard content."""

    imageType: StiImageType = StiImageType.SVG
    """[enum] Specifies the type of exported images."""

    scale: int = 100
    """The scale of an exported document."""

    renderSinglePage: bool = True
    """Export only the first page if elements require multiple pages to be rendered."""


### Helpers

    def getExportFormat(self):
        return StiDashboardExportFormat.IMAGE
    